#© 2020, The Sage Group plc or its licensors. All rights reserved
$atpFolder = read-host "Enter folder Sage X3 Automated Test Platform is installed in (leave blank to use current folder)"

if ($atpFolder -eq "") {
    $atpFolder = "$PSScriptRoot"
}

Set-Location -Path $atpFolder

try {
    $currentVersion = node -e "console.log(require('./package.json').version);"
    $newVersion = npm view @sageatp/x3-atppackage version
}
catch {
    Write-Host $_ -ForegroundColor Red
    throw "Error updating Sage X3 Automated Test Platform! Unable to detect latest version"
}

if ($currentVersion -eq $newVersion) {
    Write-Host 'Sage X3 Automated Test Platform is already up to date!' -ForegroundColor Green
    return
}

Write-Host "Updating Sage X3 Automated Test Platform to version $newVersion" -ForegroundColor Yellow

$vsCode = Get-Process code -ErrorAction SilentlyContinue
if ($vsCode) {
    Write-Error 'Please close all VS Code windows first before attempting to update Sage X3 Automated Test Platform'
    return
}

$chromedriverprocess = Get-Process *-chromedriver | Select-Object -Expand Id

if ($chromedriverprocess) {
    foreach ($process in $chromedriverprocess) {
        Stop-Process -Id $process
    }
}

try {
    Remove-Item -Path "package.json"

    Remove-Item -Path ".\Samples" -Recurse

    $currentVersionNumbers = $currentVersion.split(".")
    $newVersionNumbers = $newVersion.split(".")

    if ([int]$newVersionNumbers[0] -gt [int]$currentVersionNumbers[0] -or [int]$newVersionNumbers[1] -gt [int]$currentVersionNumbers[1]) {
        Remove-Item -Path "package-lock.json"
        Remove-Item -Path ".\node_modules" -Recurse -Force
        npm cache clean --force
    }

    npm install @sageatp/x3-atppackage --ignore-scripts

    XCopy ".\node_modules\@sageatp\x3-atppackage" "." /s /y /q > $null

    Remove-Item -Path ".\node_modules\@sageatp\x3-atppackage" -Recurse

    npm install

    if (-not (Test-Path ".\cucumber-config\parameters-cloud-chrome" -PathType leaf)) {
        Copy-Item -Path ".\cucumber-config\parameters-cloud-chrome_template" -Destination ".\cucumber-config\parameters-cloud-chrome"
    }

    $currentVersion = node -e "console.log(require('./package.json').version);"
	
    write-host "Sage X3 Automated Test Platform updated to version $currentVersion" -ForegroundColor Green
}
catch {
    Write-Host $_ -ForegroundColor Red
    throw "Error updating Sage X3 Automated Test Platform!"
}
